@@ -294,12 +294,13 @@
 		(clsql-sys:in test :oodml/select/12 :oodml/select/13 :oodml/select/14
 			      :oodml/select/15 :oodml/select/16 :oodml/select/17
 			      :oodml/select/18 :oodml/select/19 :oodml/select/20
-			      :oodml/select/21 :oodml/select/22
+			      :oodml/select/21 :oodml/select/22 :oodml/select/23
 			      :oodml/update-records/4 :oodml/update-records/4-slots
 			      :oodml/update-records/5 :oodml/update-records/5-slots
 			      :oodml/update-records/6 :oodml/update-records/7
 			      :oodml/update-records/8 :oodml/update-records/9
-			      :oodml/update-records/9-slots :oodml/update-instance/3
+			      :oodml/update-records/9-slots :oodml/update-records/10
+			      :oodml/update-records/11 :oodml/update-instance/3
 			      :oodml/update-instance/4 :oodml/update-instance/5
 			      :oodml/update-instance/6 :oodml/update-instance/7
 			      :oodml/db-auto-sync/3 :oodml/db-auto-sync/4))
